@@ -32,12 +32,14 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_SERVER_BODY_COMMAND_H_
-#define _D_HTTP_SERVER_BODY_COMMAND_H_
+#ifndef D_HTTP_SERVER_BODY_COMMAND_H
+#define D_HTTP_SERVER_BODY_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
+#include "ValueBase.h"
+#include "RpcResponse.h"
 
 namespace aria2 {
 
@@ -47,12 +49,26 @@ class HttpServer;
 
 class HttpServerBodyCommand : public Command {
 private:
-  DownloadEngine* _e;
-  SharedHandle<SocketCore> _socket;
-  SharedHandle<HttpServer> _httpServer;
-  Time _timeout;
+  DownloadEngine* e_;
+  SharedHandle<SocketCore> socket_;
+  SharedHandle<HttpServer> httpServer_;
+  Timer timeoutTimer_;
+  void sendJsonRpcErrorResponse
+  (const std::string& httpStatus,
+   int code,
+   const std::string& message,
+   const SharedHandle<ValueBase>& id,
+   const std::string& callback);
+  void sendJsonRpcResponse
+  (const rpc::RpcResponse& res,
+   const std::string& callback);
+  void sendJsonRpcBatchResponse
+  (const std::vector<rpc::RpcResponse>& results,
+   const std::string& callback);
+  rpc::RpcResponse processJsonRpcRequest(const Dict* jsondict);
+  void addHttpServerResponseCommand();
 public:
-  HttpServerBodyCommand(int32_t cuid,
+  HttpServerBodyCommand(cuid_t cuid,
                         const SharedHandle<HttpServer>& httpServer,
                         DownloadEngine* e,
                         const SharedHandle<SocketCore>& socket);
@@ -64,4 +80,4 @@ public:
 
 } // namespace aria2 
 
-#endif // _D_HTTP_SERVER_BODY_COMMAND_H_
+#endif // D_HTTP_SERVER_BODY_COMMAND_H
