@@ -34,6 +34,7 @@
 /* copyright --> */
 #include "KqueueEventPoll.h"
 
+#include <cerrno>
 #include <cstring>
 #include <algorithm>
 #include <numeric>
@@ -41,6 +42,8 @@
 #include "Command.h"
 #include "LogFactory.h"
 #include "Logger.h"
+#include "util.h"
+#include "fmt.h"
 
 #ifdef KEVENT_UDATA_INTPTR_T
 # define PTR_TO_UDATA(X) (reinterpret_cast<intptr_t>(X))
@@ -50,8 +53,9 @@
 
 namespace aria2 {
 
-KqueueEventPoll::KSocketEntry::KSocketEntry(sock_t s):
-  SocketEntry<KCommandEvent, KADNSEvent>(s) {}
+KqueueEventPoll::KSocketEntry::KSocketEntry(sock_t s)
+  : SocketEntry<KCommandEvent, KADNSEvent>(s)
+{}
 
 int accumulateEvent(int events, const KqueueEventPoll::KEvent& event)
 {
@@ -83,10 +87,9 @@ size_t KqueueEventPoll::KSocketEntry::getEvents
   return 2;
 }
 
-KqueueEventPoll::KqueueEventPoll():
-  kqEventsSize_(KQUEUE_EVENTS_MAX),
-  kqEvents_(new struct kevent[kqEventsSize_]),
-  logger_(LogFactory::getInstance())
+KqueueEventPoll::KqueueEventPoll()
+  : kqEventsSize_(KQUEUE_EVENTS_MAX),
+    kqEvents_(new struct kevent[kqEventsSize_])
 {
   kqfd_ = kqueue();
 }
@@ -94,12 +97,13 @@ KqueueEventPoll::KqueueEventPoll():
 KqueueEventPoll::~KqueueEventPoll()
 {
   if(kqfd_ != -1) {
-    int r;
-    while((r = close(kqfd_)) == -1 && errno == EINTR);
+    int r = close(kqfd_);
+    int errNum = errno;
     if(r == -1) {
-      logger_->error("Error occurred while closing kqueue file descriptor"
-                     " %d: %s",
-                     kqfd_, strerror(errno));
+      A2_LOG_ERROR(fmt("Error occurred while closing kqueue file descriptor"
+                       " %d: %s",
+                       kqfd_,
+                       util::safeStrerror(errNum).c_str()));
     }
   }
   delete [] kqEvents_;
@@ -128,8 +132,10 @@ void KqueueEventPoll::poll(const struct timeval& tv)
       }
       p->processEvents(events);
     }
+  } else if(res == -1) {
+    int errNum = errno;
+    A2_LOG_INFO(fmt("kevent error: %s", util::safeStrerror(errNum).c_str()));
   }
-
 #ifdef ENABLE_ASYNC_DNS
   // It turns out that we have to call ares_process_fd before ares's
   // own timeout and ares may create new sockets or closes socket in
@@ -167,12 +173,13 @@ bool KqueueEventPoll::addEvents
 {
   SharedHandle<KSocketEntry> socketEntry(new KSocketEntry(socket));
   std::deque<SharedHandle<KSocketEntry> >::iterator i =
-    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry);
+    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry,
+                     DerefLess<SharedHandle<KSocketEntry> >());
   int r = 0;
   struct timespec zeroTimeout = { 0, 0 };
   struct kevent changelist[2];
   size_t n;
-  if(i != socketEntries_.end() && (*i) == socketEntry) {
+  if(i != socketEntries_.end() && *(*i) == *socketEntry) {
     event.addSelf(*i);
     n = (*i)->getEvents(changelist);
   } else {
@@ -186,11 +193,11 @@ bool KqueueEventPoll::addEvents
     n = socketEntry->getEvents(changelist);
   }
   r = kevent(kqfd_, changelist, n, changelist, 0, &zeroTimeout);
+  int errNum = errno;
   if(r == -1) {
-    if(logger_->debug()) {
-      logger_->debug("Failed to add socket event %d:%s",
-                     socket, strerror(errno));
-    }
+    A2_LOG_DEBUG(fmt("Failed to add socket event %d:%s",
+                     socket,
+                     util::safeStrerror(errNum).c_str()));
     return false;
   } else {
     return true;
@@ -217,29 +224,28 @@ bool KqueueEventPoll::deleteEvents(sock_t socket,
 {
   SharedHandle<KSocketEntry> socketEntry(new KSocketEntry(socket));
   std::deque<SharedHandle<KSocketEntry> >::iterator i =
-    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry);
-  if(i != socketEntries_.end() && (*i) == socketEntry) {
+    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry,
+                     DerefLess<SharedHandle<KSocketEntry> >());
+  if(i != socketEntries_.end() && *(*i) == *socketEntry) {
     event.removeSelf(*i);
     int r = 0;
     struct timespec zeroTimeout = { 0, 0 };
     struct kevent changelist[2];
     size_t n = (*i)->getEvents(changelist);
     r = kevent(kqfd_, changelist, n, changelist, 0, &zeroTimeout);
+    int errNum = errno;
     if((*i)->eventEmpty()) {
       socketEntries_.erase(i);
     }
     if(r == -1) {
-      if(logger_->debug()) {
-        logger_->debug("Failed to delete socket event:%s", strerror(errno));
-      }
+      A2_LOG_DEBUG(fmt("Failed to delete socket event:%s",
+                       util::safeStrerror(errNum).c_str()));
       return false;
     } else {
       return true;
     }
   } else {
-    if(logger_->debug()) {
-      logger_->debug("Socket %d is not found in SocketEntries.", socket);
-    }
+    A2_LOG_DEBUG(fmt("Socket %d is not found in SocketEntries.", socket));
     return false;
   }
 }
@@ -266,7 +272,8 @@ bool KqueueEventPoll::addNameResolver
   SharedHandle<KAsyncNameResolverEntry> entry
     (new KAsyncNameResolverEntry(resolver, command));
   std::deque<SharedHandle<KAsyncNameResolverEntry> >::iterator itr =
-    std::find(nameResolverEntries_.begin(), nameResolverEntries_.end(), entry);
+    std::find_if(nameResolverEntries_.begin(), nameResolverEntries_.end(),
+                 derefEqual(entry));
   if(itr == nameResolverEntries_.end()) {
     nameResolverEntries_.push_back(entry);
     entry->addSocketEvents(this);
@@ -282,7 +289,8 @@ bool KqueueEventPoll::deleteNameResolver
   SharedHandle<KAsyncNameResolverEntry> entry
     (new KAsyncNameResolverEntry(resolver, command));
   std::deque<SharedHandle<KAsyncNameResolverEntry> >::iterator itr =
-    std::find(nameResolverEntries_.begin(), nameResolverEntries_.end(), entry);
+    std::find_if(nameResolverEntries_.begin(), nameResolverEntries_.end(),
+                 derefEqual(entry));
   if(itr == nameResolverEntries_.end()) {
     return false;
   } else {
