@@ -57,18 +57,16 @@ const std::string Request::PROTO_HTTPS("https");
 const std::string Request::PROTO_FTP("ftp");
 
 Request::Request():
-  port_(0), tryCount_(0),
+  method_(METHOD_GET),
+  tryCount_(0),
   redirectCount_(0),
   supportsPersistentConnection_(true),
   keepAliveHint_(false),
   pipeliningHint_(false),
   maxPipelinedRequest_(1),
-  method_(METHOD_GET),
-  hasPassword_(false),
-  ipv6LiteralAddress_(false),
   removalRequested_(false),
   connectedPort_(0),
-  wakeTime_(global::wallclock)
+  wakeTime_(global::wallclock())
 {}
 
 Request::~Request() {}
@@ -85,27 +83,6 @@ std::string removeFragment(const std::string& uri)
 }
 } // namespace
 
-namespace {
-std::string percentEncode(const std::string& src)
-{
-  std::string result;
-  for(std::string::const_iterator i = src.begin(), eoi = src.end(); i != eoi;
-      ++i) {
-    // Non-Printable ASCII and non-ASCII chars + some ASCII chars.
-    unsigned char c = *i;
-    if(in(c, 0x00u, 0x20u) || c >= 0x7fu ||
-       // Chromium escapes following characters. Firefox4 escapes
-       // more.
-       c == '"' || c == '<' || c == '>') {
-      result += fmt("%%%02X", c);
-    } else {
-      result += c;
-    }
-  }
-  return result;
-}
-} // namespace
-
 bool Request::setUri(const std::string& uri) {
   supportsPersistentConnection_ = true;
   uri_ = uri;
@@ -121,43 +98,66 @@ bool Request::resetUri() {
 
 void Request::setReferer(const std::string& uri)
 {
-  referer_ = previousUri_ = percentEncode(removeFragment(uri));
+  referer_ = previousUri_ = removeFragment(uri);
 }
 
 bool Request::redirectUri(const std::string& uri) {
   supportsPersistentConnection_ = true;
   ++redirectCount_;
+  if(uri.empty()) {
+    return false;
+  }
   std::string redirectedUri;
-  if(uri.find("://") == std::string::npos) {
-    // rfc2616 requires absolute URI should be provided by Location header
-    // field, but some servers don't obey this rule.
-    if(util::startsWith(uri, "/")) {
-      // abosulute path
-      redirectedUri = strconcat(protocol_, "://", host_, uri);
-    } else {
-      // relative path
-      redirectedUri = strconcat(protocol_, "://", host_, dir_, "/", uri);
-    }
+  if(util::startsWith(uri, "//")) {
+    // Network-path reference (according to RFC 3986, Section 4.2)
+    // Just complement current protocol.
+    redirectedUri = getProtocol();
+    redirectedUri += ":";
+    redirectedUri += uri;
   } else {
-    redirectedUri = uri;
+    std::string::size_type schemeEnd = uri.find("://");
+    bool absUri;
+    if(schemeEnd == std::string::npos) {
+      absUri = false;
+    } else {
+      absUri = true;
+      // Check that scheme is acceptable one.
+      for(size_t i = 0; i < schemeEnd; ++i) {
+        char c = uri[i];
+        if(!util::isAlpha(c) && !util::isDigit(c) &&
+           c != '+' && c != '-' && c != '.') {
+          absUri = false;
+          break;
+        }
+      }
+    }
+    if(absUri) {
+      redirectedUri = uri;
+    } else {
+      // rfc2616 requires absolute URI should be provided by Location header
+      // field, but some servers don't obey this rule.
+      // UPDATE: draft-ietf-httpbis-p2-semantics-18 now allows this.
+      uri::UriStruct rus(us_);
+      rus.query.clear();
+      rus.file.clear();
+      size_t offset = 0;
+      if(uri[0] == '/') {
+        // abosulute path
+        rus.dir.clear();
+        offset = 1;
+      }
+      redirectedUri = uri::construct(rus);
+      redirectedUri.append(uri.begin()+offset, uri.end());
+    }
   }
   return parseUri(redirectedUri);
 }
 
 bool Request::parseUri(const std::string& srcUri) {
-  currentUri_ = percentEncode(removeFragment(srcUri));
+  currentUri_ = removeFragment(srcUri);
   uri::UriStruct us;
   if(uri::parse(us, currentUri_)) {
-    protocol_.swap(us.protocol);
-    host_.swap(us.host);
-    port_ = us.port;
-    dir_.swap(us.dir);
-    file_.swap(us.file);
-    query_.swap(us.query);
-    username_.swap(us.username);
-    password_.swap(us.password);
-    hasPassword_ = us.hasPassword;
-    ipv6LiteralAddress_ = us.ipv6LiteralAddress;
+    us_.swap(us);
     return true;
   } else {
     return false;
@@ -169,7 +169,7 @@ void Request::resetRedirectCount()
   redirectCount_ = 0;
 }
   
-void Request::setMaxPipelinedRequest(unsigned int num)
+void Request::setMaxPipelinedRequest(int num)
 {
   maxPipelinedRequest_ = num;
 }
@@ -188,7 +188,10 @@ const SharedHandle<PeerStat>& Request::initPeerStat()
 std::string Request::getURIHost() const
 {
   if(isIPv6LiteralAddress()) {
-    return strconcat("[", getHost(), "]");
+    std::string s = "[";
+    s += getHost();
+    s += "]";
+    return s;
   } else {
     return getHost();
   }
