@@ -22,7 +22,7 @@ class MSEHandshakeTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testHandshake);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<DownloadContext> _dctx;
+  SharedHandle<DownloadContext> dctx_;
 
   void doHandshake(const SharedHandle<MSEHandshake>& initiator,
                    const SharedHandle<MSEHandshake>& receiver);
@@ -30,13 +30,12 @@ private:
 public:
   void setUp()
   {
-    _dctx.reset(new DownloadContext());
+    dctx_.reset(new DownloadContext());
     unsigned char infoHash[20];
     memset(infoHash, 0, sizeof(infoHash));
-    BDE torrentAttrs = BDE::dict();
-    torrentAttrs[bittorrent::INFO_HASH] =
-      std::string(&infoHash[0], &infoHash[arrayLength(infoHash)]);
-    _dctx->setAttribute(bittorrent::BITTORRENT, torrentAttrs);
+    SharedHandle<TorrentAttribute> torrentAttrs(new TorrentAttribute());
+    torrentAttrs->infoHash = std::string(vbegin(infoHash), vend(infoHash));
+    dctx_->setAttribute(bittorrent::BITTORRENT, torrentAttrs);
   }
 
   void testHandshake();
@@ -45,8 +44,9 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(MSEHandshakeTest);
 
-static std::pair<SharedHandle<SocketCore>,
-                 SharedHandle<SocketCore> > createSocketPair()
+namespace {
+std::pair<SharedHandle<SocketCore>, SharedHandle<SocketCore> >
+createSocketPair()
 {
   SharedHandle<SocketCore> initiatorSock(new SocketCore());
 
@@ -65,33 +65,66 @@ static std::pair<SharedHandle<SocketCore>,
   return std::pair<SharedHandle<SocketCore>,
     SharedHandle<SocketCore> >(initiatorSock, receiverSock);
 }
+} // namespace
 
 void MSEHandshakeTest::doHandshake(const SharedHandle<MSEHandshake>& initiator, const SharedHandle<MSEHandshake>& receiver)
 {
   initiator->sendPublicKey();
-
-  while(!receiver->receivePublicKey());
+  while(initiator->getWantWrite()) {
+    initiator->send();
+  }
+  while(!receiver->receivePublicKey()) {
+    receiver->read();
+  }
   receiver->sendPublicKey();
+  while(receiver->getWantWrite()) {
+    receiver->send();
+  }
 
-  while(!initiator->receivePublicKey());
-  initiator->initCipher(bittorrent::getInfoHash(_dctx));
+  while(!initiator->receivePublicKey()) {
+    initiator->read();
+  }
+  initiator->initCipher(bittorrent::getInfoHash(dctx_));
   initiator->sendInitiatorStep2();
+  while(initiator->getWantWrite()) {
+    initiator->send();
+  }
 
-  while(!receiver->findReceiverHashMarker());
-  std::deque<SharedHandle<DownloadContext> > contexts;
-  contexts.push_back(_dctx);
-  while(!receiver->receiveReceiverHashAndPadCLength(contexts));
-  while(!receiver->receivePad());
-  while(!receiver->receiveReceiverIALength());
-  while(!receiver->receiveReceiverIA());
+  while(!receiver->findReceiverHashMarker()) {
+    receiver->read();
+  }
+  std::vector<SharedHandle<DownloadContext> > contexts;
+  contexts.push_back(dctx_);
+  while(!receiver->receiveReceiverHashAndPadCLength(contexts)) {
+    receiver->read();
+  }
+  while(!receiver->receivePad()) {
+    receiver->read();
+  }
+  while(!receiver->receiveReceiverIALength()) {
+    receiver->read();
+  }
+  while(!receiver->receiveReceiverIA()) {
+    receiver->read();
+  }
   receiver->sendReceiverStep2();
+  while(receiver->getWantWrite()) {
+    receiver->send();
+  }
 
-  while(!initiator->findInitiatorVCMarker());
-  while(!initiator->receiveInitiatorCryptoSelectAndPadDLength());
-  while(!initiator->receivePad());
+  while(!initiator->findInitiatorVCMarker()) {
+    initiator->read();
+  }
+  while(!initiator->receiveInitiatorCryptoSelectAndPadDLength()) {
+    initiator->read();
+  }
+  while(!initiator->receivePad()) {
+    initiator->read();
+  }
 }
 
-static SharedHandle<MSEHandshake>
+namespace {
+SharedHandle<MSEHandshake>
 createMSEHandshake(SharedHandle<SocketCore> socket, bool initiator,
                    const Option* option)
 {
@@ -99,6 +132,7 @@ createMSEHandshake(SharedHandle<SocketCore> socket, bool initiator,
   h->initEncryptionFacility(initiator);
   return h;
 }
+} // namespace
 
 void MSEHandshakeTest::testHandshake()
 {
